@@ -160,16 +160,16 @@ DataFrame <- function(..., row.names = NULL, check.names = TRUE)
       ncols[i] <- ncol(element)
       varlist[[i]] <- as.list(element, use.names = FALSE)
       if (!is(listData[[i]], "AsIs")) {
-        if (((length(dim(listData[[i]])) > 1) || (ncol(element) > 1)))
+        if (((length(dim(listData[[i]])) > 1L) || (ncol(element) > 1L) ||
+             is.list(listData[[i]])))
           {
             if (emptynames[i])
               varnames[[i]] <- colnames(element)
             else
               varnames[[i]] <- paste(varnames[[i]], colnames(element), sep = ".")
-          } else if (is.list(listData[[i]]) && length(names(listData[[i]])))
-            varnames[[i]] <- names(element)
+          }
       }
-      if (is.null(row.names))
+      if (missing(row.names))
         row.names <- rownames(element)
     }
     nr <- max(nrows)
@@ -624,7 +624,7 @@ setAs("Vector", "DataFrame", .VectorAsDataFrame)
 ## is this a bug or a feature?
 setAs("list", "DataFrame",
       function(from) {
-        do.call(DataFrame, c(from, check.names = FALSE))
+        do.call(DataFrame, c(from, check.names = is.null(names(from))))
       })
 
 setAs("NULL", "DataFrame", function(from) as(list(), "DataFrame"))
@@ -652,8 +652,9 @@ setAs("ANY", "DataTable_OR_NULL", function(from) as(from, "DataFrame"))
 ###
 
 cbind.DataFrame <- function(..., deparse.level = 1) {
-  ans <- DataFrame(...)
-  mcols(ans) <- rbind_mcols(...)
+  dfs <- lapply(list(...), as, "DataFrame", strict=FALSE)
+  ans <- DataFrame(dfs)
+  mcols(ans) <- do.call(rbind_mcols, dfs)
   ans
 }
 
