@@ -43,7 +43,16 @@ setMethod("pcompareRecursively", "list", function(x) TRUE)
         return(OP1_Vector_method(x, ...))
     }
     compress_ans <- !is(x, "SimpleList")
-    ANS_CONSTRUCTOR(lapply(x, OP1, ...), compress=compress_ans)
+    ## Note that we should just be able to do
+    ##   y <- lapply(x, OP1, ...)
+    ## instead of the extremely obfuscated form below (which, in a bug-free
+    ## world, should be equivalent to the simple form above).
+    ## However, because of a regression in R 3.4.2, using the simple form
+    ## above doesn't seem to work properly if OP1 is a generic function with
+    ## dispatch on ... (e.g. order()). The form below seems to work though,
+    ## so we use it as a temporary workaround.
+    y <- lapply(x, function(xi) do.call(OP1, list(xi, ...)))
+    ANS_CONSTRUCTOR(y, compress=compress_ans)
 }
 
 ### Apply a binary operator.
@@ -99,15 +108,15 @@ setMethod("pcompareRecursively", "list", function(x) TRUE)
 ###
 
 setMethods("pcompare", .OP2_SIGNATURES,
-    function(x, y) .op2_apply(pcompare, x, y, ANS_CONSTRUCTOR=IntegerList)
+           function(x, y) .op2_apply(pcompare, x, y, ANS_CONSTRUCTOR=IRanges::IntegerList)
 )
 
 setMethods("==", .OP2_SIGNATURES,
-    function(e1, e2) .op2_apply(`==`, e1, e2, ANS_CONSTRUCTOR=LogicalList)
+           function(e1, e2) .op2_apply(`==`, e1, e2, ANS_CONSTRUCTOR=IRanges::LogicalList)
 )
 
 setMethods("<=", .OP2_SIGNATURES,
-    function(e1, e2) .op2_apply(`<=`, e1, e2, ANS_CONSTRUCTOR=LogicalList)
+           function(e1, e2) .op2_apply(`<=`, e1, e2, ANS_CONSTRUCTOR=IRanges::LogicalList)
 )
 
 ### The remaining comparison binary operators (!=, >=, <, >) will work
@@ -117,9 +126,9 @@ setMethod("!", "List",
     function(x)
     {
         if (is(x, "RleList")) {
-            ANS_CONSTRUCTOR <- RleList
+            ANS_CONSTRUCTOR <- IRanges::RleList
         } else {
-            ANS_CONSTRUCTOR <- LogicalList
+            ANS_CONSTRUCTOR <- IRanges::LogicalList
         }
         .op1_apply(`!`, x, ANS_CONSTRUCTOR=ANS_CONSTRUCTOR)
     }
@@ -134,9 +143,9 @@ setMethods("match", .OP2_SIGNATURES,
     function(x, table, nomatch=NA_integer_, incomparables=NULL, ...)
     {
         if (is(x, "RleList")) {
-            ANS_CONSTRUCTOR <- RleList
+            ANS_CONSTRUCTOR <- IRanges::RleList
         } else {
-            ANS_CONSTRUCTOR <- IntegerList
+            ANS_CONSTRUCTOR <- IRanges::IntegerList
         }
         .op2_apply(match, x, table,
                    nomatch=nomatch, incomparables=incomparables, ...,
@@ -166,7 +175,7 @@ setMethods("match", list(c("List", "vector"), c("List", "Vector")),
 {
     .op1_apply(duplicated, x,
                incomparables=incomparables, fromLast=fromLast, ...,
-               ANS_CONSTRUCTOR=LogicalList)
+               ANS_CONSTRUCTOR=IRanges::LogicalList)
 }
 setMethod("duplicated", "List", .duplicated.List)
 
@@ -188,9 +197,9 @@ setMethod("is.na", "List",
     function(x)
     {
         if (is(x, "RleList")) {
-            ANS_CONSTRUCTOR <- RleList
+            ANS_CONSTRUCTOR <- IRanges::RleList
         } else {
-            ANS_CONSTRUCTOR <- LogicalList
+            ANS_CONSTRUCTOR <- IRanges::LogicalList
         }
         .op1_apply(is.na, x, ANS_CONSTRUCTOR=ANS_CONSTRUCTOR)
     }
@@ -202,7 +211,8 @@ setMethod("is.na", "List",
 ###
 
 setMethod("order", "List",
-    function(..., na.last=TRUE, decreasing=FALSE, method=c("shell", "radix"))
+    function(..., na.last=TRUE, decreasing=FALSE,
+                  method=c("auto", "shell", "radix"))
     {
         args <- list(...)
         if (length(args) != 1L)
@@ -210,7 +220,7 @@ setMethod("order", "List",
                  "can only take one input object")
         .op1_apply(order, args[[1L]],
                    na.last=na.last, decreasing=decreasing, method=method,
-                   ANS_CONSTRUCTOR=IntegerList)
+                   ANS_CONSTRUCTOR=IRanges::IntegerList)
     }
 )
 
@@ -229,7 +239,7 @@ setMethod("rank", "List",
     {
         .op1_apply(rank, x,
                    na.last=na.last, ties.method=ties.method,
-                   ANS_CONSTRUCTOR=IntegerList)
+                   ANS_CONSTRUCTOR=IRanges::IntegerList)
     }
 )
 
