@@ -8,7 +8,7 @@ setClass("Rle",
     contains="Vector",
     representation(
         values="vector_OR_factor",
-        lengths="integer_OR_Linteger"
+        lengths="integer_OR_LLint"
     ),
     prototype(
         values=logical(0),
@@ -69,12 +69,12 @@ new_Rle <- function(values=logical(0), lengths=NULL)
 {
     stopifnot(is(values, "vector_OR_factor"))
     if (!is.null(lengths)) {
-        if (!(is.numeric(lengths) || is.Linteger(lengths)))
-            stop("'lengths' must be NULL or a numeric or Linteger vector")
+        if (!(is.numeric(lengths) || is.LLint(lengths)))
+            stop("'lengths' must be NULL or a numeric or LLint vector")
         if (anyNA(lengths))
             stop("'lengths' cannot contain NAs")
         if (is.double(lengths)) {
-            suppressWarnings(lengths <- as.Linteger(lengths))
+            suppressWarnings(lengths <- as.LLint(lengths))
             if (anyNA(lengths))
                 stop("Rle vector is too long")
         }
@@ -691,17 +691,23 @@ setMethod("match", c("Rle", "Rle"),
     }
 )
 
-### FIXME: Remove in R 3.3
 setMethod("order", "Rle",
-    function(..., na.last=TRUE, decreasing=FALSE,
-                  method=c("auto", "shell", "radix"))
-    {
-        args <- lapply(unname(list(...)), decodeRle)
+          function(..., na.last=TRUE, decreasing=FALSE,
+                   method=c("auto", "shell", "radix"))
+{
+    args <- list(...)
+    if (length(args) == 1L) {
+        x <- args[[1L]]
+        o <- order(runValue(x), na.last=na.last, decreasing=decreasing,
+                   method=method)
+        mseq(start(x)[o], end(x)[o])
+    } else {
+        args <- lapply(unname(args), decodeRle)
         do.call(order, c(args, list(na.last=na.last,
                                     decreasing=decreasing,
                                     method=method)))
     }
-)
+})
 
 .sort.Rle <- function(x, decreasing=FALSE, na.last=NA, ...)
 {
@@ -862,7 +868,7 @@ setMethod("show", "Rle",
               nr <- nrun(object)
               halfWidth <- getOption("width") %/% 2L
               cat(classNameForDisplay(runValue(object)),
-                  "-Rle of length ", as.character(as.Linteger(lo)),
+                  "-Rle of length ", as.character(as.LLint(lo)),
                   " with ", nr, ifelse(nr == 1, " run\n", " runs\n"), sep = "")
               first <- max(1L, halfWidth)
               showMatrix <-
