@@ -60,8 +60,6 @@ setMethods("<", .OP2_SIGNATURES, function(e1, e2) { !(e2 <= e1) })
 
 setMethods(">", .OP2_SIGNATURES, function(e1, e2) { !(e1 <= e2) })
 
-compare <- function(...) .Defunct("pcompare")
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### selfmatch()
@@ -275,16 +273,6 @@ setMethod("countMatches", c("ANY", "ANY"), .countMatches.default)
 ### The method below is implemented on top of order().
 ###
 
-### S3/S4 combo for sort.Vector
-.sort.Vector <- function(x, decreasing=FALSE, na.last=NA, by)
-{
-    if (!missing(by)) {
-        i <- orderBy(by, x, decreasing=decreasing, na.last=na.last)
-    } else {
-        i <- order(x, na.last=na.last, decreasing=decreasing)
-    }
-    extractROWS(x, i)
-}
 sort.Vector <- function(x, decreasing=FALSE, ...)
     sort(x, decreasing=decreasing, ...)
 setMethod("sort", "Vector", .sort.Vector)
@@ -307,30 +295,24 @@ orderBy <- function(formula, x, decreasing=FALSE, na.last=TRUE) {
   do.call(order, c(decreasing=decreasing, na.last=na.last, values))
 }
 
-setMethod("xtfrm", "Vector", function(x) {
-    as.vector(rank(x, ties.method = "min", na.last = "keep"))
-})
-
 setMethod("rank", "Vector",
-          function(x, na.last=TRUE,
-                   ties.method=c("average", "first", "random", "max", "min"))
-          {
-            if (missing(ties.method)) {
-              ties.method <- "first"
-            }
-            ties.method <- match.arg(ties.method)
-            if (ties.method == "first") {
-              oo <- order(x, na.last=na.last)
-              ## 'ans' is the reverse permutation of 'oo'
-              ans <- integer(length(oo))
-              ans[oo] <- seq_len(length(oo))
-              ans
-            } else if (ties.method == "min") {
-              rank(x, na.last=na.last, ties.method="first")[selfmatch(x)]
-            } else {
-              stop("only tie methods \"first\" and \"min\" are supported")
-            }
-          })
+    function(x, na.last=TRUE,
+             ties.method=c("average", "first", "last", "random", "max", "min"))
+    {
+        ties.method <- match.arg(ties.method)
+        oo <- order(x, na.last=na.last)
+        ## 'ans' is the reverse permutation of 'oo'.
+        ans <- integer(length(oo))
+        ans[oo] <- seq_along(oo)
+        if (ties.method == "first")
+            return(ans)
+        ans <- ans[selfmatch(x)]
+        if (ties.method == "min")
+            return(ans)
+        ## Other ties methods.
+        rank(ans, ties.method=ties.method)
+    }
+)
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
