@@ -156,16 +156,10 @@ labeledLine <-
 }
 
 ### Exported!
-get_showHeadLines <- function()
-{
-    .get_showLines(5L, "showHeadLines")
-}
+get_showHeadLines <- function() .get_showLines(5L, "showHeadLines")
 
 ### Exported!
-get_showTailLines <- function()
-{
-    .get_showLines(5L, "showTailLines")
-}
+get_showTailLines <- function() .get_showLines(5L, "showTailLines")
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -329,3 +323,100 @@ toNumSnippet <- function(x, max.width)
     paste(paste(ans_head, collapse=" "), "...", paste(ans_tail, collapse=" "))
 }
 
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### classNameForDisplay()
+###
+
+### Exported!
+setGeneric("classNameForDisplay",
+    function(x) standardGeneric("classNameForDisplay"))
+
+setMethod("classNameForDisplay", "ANY",
+   function(x)
+   {
+       ## Selecting the 1st element guarantees that we return a single string
+       ## (e.g. on an ordered factor, class(x) returns a character vector of
+       ## length 2).
+       class(x)[1L]
+   }
+)
+
+.drop_AsIs <- function(x)
+{
+    #x_class <- class(x)
+    #if (x_class[[1L]] == "AsIs")
+    #    class(x) <- x_class[-1L]
+
+    ## Simpler, and probably more robust, than the above.
+    class(x) <- setdiff(class(x), "AsIs")
+    x
+}
+
+setMethod("classNameForDisplay", "AsIs",
+    function(x) classNameForDisplay(.drop_AsIs(x))
+)
+
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### showAsCell()
+###
+### All "showAsCell" methods should return a character vector.
+###
+
+### Exported!
+setGeneric("showAsCell",
+    function(object) standardGeneric("showAsCell")
+)
+
+### Must work on any array-like object (i.e. on any object with 2 dimensions
+### or more) e.g. ordinary array or matrix, Matrix, data.frame, DataFrame,
+### data.table, etc...
+.showAsCell_array <- function(object)
+{
+    if (length(dim(object)) > 2L)
+        dim(object) <- c(nrow(object), prod(tail(dim(object), -1L)))
+    object_ncol <- ncol(object)
+    if (object_ncol == 0L)
+        return(rep.int("", nrow(object)))
+    object <- lapply(head(seq_len(object_ncol), 3L),
+                     function(i) object[ , i, drop=TRUE])
+    ans <- do.call(paste, c(object, list(sep=":")))
+    if (object_ncol > 3L)
+        ans <- paste0(ans, ":...")
+    ans
+}
+
+.default_showAsCell <- function(object)
+{
+  ## Some objects like SplitDataFrameList are not array-like but have
+  ## a "dim" method that return a matrix!
+  if (length(dim(object)) >= 2L && !is.matrix(dim(object)))
+    return(.showAsCell_array(object))
+  if (NROW(object) == 0L)
+    return(character(0L))
+  if (is.list(object) || is(object, "List")) {
+    vapply(object, function(x) {
+      str <- paste(head(unlist(x), 3L), collapse = ",")
+      if (length(x) > 3L)
+        str <- paste0(str, ",...")
+      str
+    }, character(1L))
+  } else {
+    attempt <- try(as.vector(object), silent=TRUE)
+    if (is(attempt, "try-error"))
+      rep.int("########", length(object))
+    else attempt
+  }
+}
+
+setMethod("showAsCell", "ANY", .default_showAsCell)
+
+setMethod("showAsCell", "AsIs",
+    function(object) showAsCell(.drop_AsIs(object))
+)
+
+### Mmmh... these methods don't return a character vector. Is that ok?
+setMethod("showAsCell", "Date", function(object) object)
+setMethod("showAsCell", "POSIXt", function(object) object)
+
