@@ -181,6 +181,11 @@ void IntAE_set_val(
 	int val
 );
 
+void IntAE_extend(
+	IntAE *ae,
+	size_t new_buflength
+);
+
 void IntAE_insert_at(
 	IntAE *ae,
 	size_t at,
@@ -244,6 +249,11 @@ size_t IntAEAE_set_nelt(
 	size_t nelt
 );
 
+void IntAEAE_extend(
+	IntAEAE *aeae,
+	size_t new_buflength
+);
+
 void IntAEAE_insert_at(
 	IntAEAE *aeae,
 	size_t at,
@@ -291,6 +301,11 @@ size_t IntPairAE_set_nelt(
 	size_t nelt
 );
 
+void IntPairAE_extend(
+	IntPairAE *ae,
+	size_t new_buflength
+);
+
 void IntPairAE_insert_at(
 	IntPairAE *ae,
 	size_t at,
@@ -310,6 +325,11 @@ size_t IntPairAEAE_set_nelt(
 	size_t nelt
 );
 
+void IntPairAEAE_extend(
+	IntPairAEAE *aeae,
+	size_t new_buflength
+);
+
 void IntPairAEAE_insert_at(
 	IntPairAEAE *aeae,
 	size_t at,
@@ -333,6 +353,11 @@ void LLongAE_set_val(
 	long long val
 );
 
+void LLongAE_extend(
+	LLongAE *ae,
+	size_t new_buflength
+);
+
 void LLongAE_insert_at(
 	LLongAE *ae,
 	size_t at,
@@ -352,6 +377,11 @@ size_t CharAE_set_nelt(
 	size_t nelt
 );
 
+void CharAE_extend(
+	CharAE *ae,
+	size_t new_buflength
+);
+
 void CharAE_insert_at(
 	CharAE *ae,
 	size_t at,
@@ -373,6 +403,8 @@ void CharAE_delete_at(
 	size_t nelt
 );
 
+SEXP new_CHARSXP_from_CharAE(const CharAE *ae);
+
 SEXP new_RAW_from_CharAE(const CharAE *ae);
 
 SEXP new_LOGICAL_from_CharAE(const CharAE *ae);
@@ -384,6 +416,11 @@ size_t CharAEAE_set_nelt(
 	size_t nelt
 );
 
+void CharAEAE_extend(
+	CharAEAE *aeae,
+	size_t new_buflength
+);
+
 void CharAEAE_insert_at(
 	CharAEAE *aeae,
 	size_t at,
@@ -409,16 +446,16 @@ SEXP new_CHARACTER_from_CharAEAE(const CharAEAE *aeae);
 const char *get_classname(SEXP x);
 
 /*
- * Linteger_class.c
+ * LLint_class.c
  */
 
-int is_Linteger(SEXP x);
+int is_LLint(SEXP x);
 
-R_xlen_t get_Linteger_length(SEXP x);
+R_xlen_t get_LLint_length(SEXP x);
 
-long long int *get_Linteger_dataptr(SEXP x);
+long long int *get_LLint_dataptr(SEXP x);
 
-SEXP alloc_Linteger(const char *classname, R_xlen_t length);
+SEXP alloc_LLint(const char *classname, R_xlen_t length);
 
 /*
  * subsetting_utils.c
@@ -467,7 +504,7 @@ SEXP list_as_data_frame(
 );
 
 /*
- * int_utils.c
+ * integer_utils.c
  */
 
 int check_integer_pairs(
