@@ -18,16 +18,16 @@ static const R_CallMethodDef callMethods[] = {
 /* anyMissing.c */
 	CALLMETHOD_DEF(anyMissing, 1),
 
-/* Linteger_class.c */
-	CALLMETHOD_DEF(make_RAW_from_NA_LINTEGER, 0),
-	CALLMETHOD_DEF(new_Linteger_from_LOGICAL, 1),
-	CALLMETHOD_DEF(new_Linteger_from_INTEGER, 1),
-	CALLMETHOD_DEF(new_Linteger_from_NUMERIC, 1),
-	CALLMETHOD_DEF(new_Linteger_from_CHARACTER, 1),
-	CALLMETHOD_DEF(new_LOGICAL_from_Linteger, 1),
-	CALLMETHOD_DEF(new_INTEGER_from_Linteger, 1),
-	CALLMETHOD_DEF(new_NUMERIC_from_Linteger, 1),
-	CALLMETHOD_DEF(new_CHARACTER_from_Linteger, 1),
+/* LLint_class.c */
+	CALLMETHOD_DEF(make_RAW_from_NA_LLINT, 0),
+	CALLMETHOD_DEF(new_LLint_from_LOGICAL, 1),
+	CALLMETHOD_DEF(new_LLint_from_INTEGER, 1),
+	CALLMETHOD_DEF(new_LLint_from_NUMERIC, 1),
+	CALLMETHOD_DEF(new_LLint_from_CHARACTER, 1),
+	CALLMETHOD_DEF(new_LOGICAL_from_LLint, 1),
+	CALLMETHOD_DEF(new_INTEGER_from_LLint, 1),
+	CALLMETHOD_DEF(new_NUMERIC_from_LLint, 1),
+	CALLMETHOD_DEF(new_CHARACTER_from_LLint, 1),
 
 /* subsetting_utils.c */
 	CALLMETHOD_DEF(vector_OR_factor_extract_positions, 2),
@@ -37,14 +37,10 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(sapply_NROW, 1),
 
 /* logical_utils.c */
-	CALLMETHOD_DEF(logical_as_compact_bitvector, 1),
-	CALLMETHOD_DEF(compact_bitvector_as_logical, 2),
-	CALLMETHOD_DEF(subset_compact_bitvector, 2),
-	CALLMETHOD_DEF(compact_bitvector_bit_count, 1),
-	CALLMETHOD_DEF(compact_bitvector_last_bit, 1),
-	CALLMETHOD_DEF(compact_bitvector_set_op, 3),
+	CALLMETHOD_DEF(logical_sum, 2),
+	CALLMETHOD_DEF(logical2_sum, 2),
 
-/* int_utils.c */
+/* integer_utils.c */
 	CALLMETHOD_DEF(Integer_any_missing_or_outside, 3),
 	CALLMETHOD_DEF(Integer_diff_with_0, 1),
 	CALLMETHOD_DEF(Integer_diff_with_last, 2),
@@ -69,7 +65,7 @@ static const R_CallMethodDef callMethods[] = {
 	CALLMETHOD_DEF(Integer_fancy_mseq, 3),
 	CALLMETHOD_DEF(findIntervalAndStartFromWidth, 2),
 
-/* str_utils.c */
+/* character_utils.c */
 	CALLMETHOD_DEF(unstrsplit_list, 2),
 	CALLMETHOD_DEF(safe_strexplode, 1),
 	CALLMETHOD_DEF(strsplit_as_list_of_ints, 2),
@@ -139,6 +135,7 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_IntAE_get_nelt);
 	REGISTER_CCALLABLE(_IntAE_set_nelt);
 	REGISTER_CCALLABLE(_IntAE_set_val);
+	REGISTER_CCALLABLE(_IntAE_extend);
 	REGISTER_CCALLABLE(_IntAE_insert_at);
 	REGISTER_CCALLABLE(_new_IntAE);
 	REGISTER_CCALLABLE(_IntAE_append);
@@ -152,6 +149,7 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_new_IntAE_from_CHARACTER);
 	REGISTER_CCALLABLE(_IntAEAE_get_nelt);
 	REGISTER_CCALLABLE(_IntAEAE_set_nelt);
+	REGISTER_CCALLABLE(_IntAEAE_extend);
 	REGISTER_CCALLABLE(_IntAEAE_insert_at);
 	REGISTER_CCALLABLE(_new_IntAEAE);
 	REGISTER_CCALLABLE(_IntAEAE_pappend);
@@ -162,28 +160,34 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_IntAEAE_toEnvir);
 	REGISTER_CCALLABLE(_IntPairAE_get_nelt);
 	REGISTER_CCALLABLE(_IntPairAE_set_nelt);
+	REGISTER_CCALLABLE(_IntPairAE_extend);
 	REGISTER_CCALLABLE(_IntPairAE_insert_at);
 	REGISTER_CCALLABLE(_new_IntPairAE);
 	REGISTER_CCALLABLE(_IntPairAEAE_get_nelt);
 	REGISTER_CCALLABLE(_IntPairAEAE_set_nelt);
+	REGISTER_CCALLABLE(_IntPairAEAE_extend);
 	REGISTER_CCALLABLE(_IntPairAEAE_insert_at);
 	REGISTER_CCALLABLE(_new_IntPairAEAE);
 	REGISTER_CCALLABLE(_LLongAE_get_nelt);
 	REGISTER_CCALLABLE(_LLongAE_set_nelt);
 	REGISTER_CCALLABLE(_LLongAE_set_val);
+	REGISTER_CCALLABLE(_LLongAE_extend);
 	REGISTER_CCALLABLE(_LLongAE_insert_at);
 	REGISTER_CCALLABLE(_new_LLongAE);
 	REGISTER_CCALLABLE(_CharAE_get_nelt);
 	REGISTER_CCALLABLE(_CharAE_set_nelt);
+	REGISTER_CCALLABLE(_CharAE_extend);
 	REGISTER_CCALLABLE(_CharAE_insert_at);
 	REGISTER_CCALLABLE(_new_CharAE);
 	REGISTER_CCALLABLE(_new_CharAE_from_string);
 	REGISTER_CCALLABLE(_CharAE_append_string);
 	REGISTER_CCALLABLE(_CharAE_delete_at);
+	REGISTER_CCALLABLE(_new_CHARSXP_from_CharAE);
 	REGISTER_CCALLABLE(_new_RAW_from_CharAE);
 	REGISTER_CCALLABLE(_new_LOGICAL_from_CharAE);
 	REGISTER_CCALLABLE(_CharAEAE_get_nelt);
 	REGISTER_CCALLABLE(_CharAEAE_set_nelt);
+	REGISTER_CCALLABLE(_CharAEAE_extend);
 	REGISTER_CCALLABLE(_CharAEAE_insert_at);
 	REGISTER_CCALLABLE(_new_CharAEAE);
 	REGISTER_CCALLABLE(_CharAEAE_append_string);
@@ -192,11 +196,11 @@ void R_init_S4Vectors(DllInfo *info)
 /* SEXP_utils.c */
 	REGISTER_CCALLABLE(_get_classname);
 
-/* Linteger_class.c */
-	REGISTER_CCALLABLE(_is_Linteger);
-	REGISTER_CCALLABLE(_get_Linteger_length);
-	REGISTER_CCALLABLE(_get_Linteger_dataptr);
-	REGISTER_CCALLABLE(_alloc_Linteger);
+/* LLint_class.c */
+	REGISTER_CCALLABLE(_is_LLint);
+	REGISTER_CCALLABLE(_get_LLint_length);
+	REGISTER_CCALLABLE(_get_LLint_dataptr);
+	REGISTER_CCALLABLE(_alloc_LLint);
 
 /* subsetting_utils.c */
 	REGISTER_CCALLABLE(_copy_vector_block);
@@ -207,7 +211,7 @@ void R_init_S4Vectors(DllInfo *info)
 	REGISTER_CCALLABLE(_vector_memcmp);
 	REGISTER_CCALLABLE(_list_as_data_frame);
 
-/* int_utils.c */
+/* integer_utils.c */
 	REGISTER_CCALLABLE(_check_integer_pairs);
 	REGISTER_CCALLABLE(_find_interv_and_start_from_width);
 
