@@ -225,6 +225,11 @@ void _IntAE_set_val(
 	int val
 );
 
+void _IntAE_extend(
+	IntAE *ae,
+	size_t new_buflength
+);
+
 void _IntAE_insert_at(
 	IntAE *ae,
 	size_t at,
@@ -288,6 +293,11 @@ size_t _IntAEAE_set_nelt(
 	size_t nelt
 );
 
+void _IntAEAE_extend(
+	IntAEAE *aeae,
+	size_t new_buflength
+);
+
 void _IntAEAE_insert_at(
 	IntAEAE *aeae,
 	size_t at,
@@ -335,6 +345,11 @@ size_t _IntPairAE_set_nelt(
 	size_t nelt
 );
 
+void _IntPairAE_extend(
+	IntPairAE *ae,
+	size_t new_buflength
+);
+
 void _IntPairAE_insert_at(
 	IntPairAE *ae,
 	size_t at,
@@ -354,6 +369,11 @@ size_t _IntPairAEAE_set_nelt(
 	size_t nelt
 );
 
+void _IntPairAEAE_extend(
+	IntPairAEAE *aeae,
+	size_t new_buflength
+);
+
 void _IntPairAEAE_insert_at(
 	IntPairAEAE *aeae,
 	size_t at,
@@ -377,6 +397,11 @@ void _LLongAE_set_val(
 	long long val
 );
 
+void _LLongAE_extend(
+	LLongAE *ae,
+	size_t new_buflength
+);
+
 void _LLongAE_insert_at(
 	LLongAE *ae,
 	size_t at,
@@ -396,6 +421,11 @@ size_t _CharAE_set_nelt(
 	size_t nelt
 );
 
+void _CharAE_extend(
+	CharAE *ae,
+	size_t new_buflength
+);
+
 void _CharAE_insert_at(
 	CharAE *ae,
 	size_t at,
@@ -417,6 +447,8 @@ void _CharAE_delete_at(
 	size_t nelt
 );
 
+SEXP _new_CHARSXP_from_CharAE(const CharAE *ae);
+
 SEXP _new_RAW_from_CharAE(const CharAE *ae);
 
 SEXP _new_LOGICAL_from_CharAE(const CharAE *ae);
@@ -428,6 +460,11 @@ size_t _CharAEAE_set_nelt(
 	size_t nelt
 );
 
+void _CharAEAE_extend(
+	CharAEAE *aeae,
+	size_t new_buflength
+);
+
 void _CharAEAE_insert_at(
 	CharAEAE *aeae,
 	size_t at,
@@ -459,33 +496,33 @@ const char *_get_classname(SEXP x);
 SEXP anyMissing(SEXP x);
 
 
-/* Linteger_class.c */
+/* LLint_class.c */
 
-int _is_Linteger(SEXP x);
+int _is_LLint(SEXP x);
 
-SEXP make_RAW_from_NA_LINTEGER();
+SEXP make_RAW_from_NA_LLINT();
 
-R_xlen_t _get_Linteger_length(SEXP x);
+R_xlen_t _get_LLint_length(SEXP x);
 
-long long int *_get_Linteger_dataptr(SEXP x);
+long long int *_get_LLint_dataptr(SEXP x);
 
-SEXP _alloc_Linteger(const char *classname, R_xlen_t length);
+SEXP _alloc_LLint(const char *classname, R_xlen_t length);
 
-SEXP new_Linteger_from_LOGICAL(SEXP x);
+SEXP new_LLint_from_LOGICAL(SEXP x);
 
-SEXP new_Linteger_from_INTEGER(SEXP x);
+SEXP new_LLint_from_INTEGER(SEXP x);
 
-SEXP new_Linteger_from_NUMERIC(SEXP x);
+SEXP new_LLint_from_NUMERIC(SEXP x);
 
-SEXP new_Linteger_from_CHARACTER(SEXP x);
+SEXP new_LLint_from_CHARACTER(SEXP x);
 
-SEXP new_LOGICAL_from_Linteger(SEXP x);
+SEXP new_LOGICAL_from_LLint(SEXP x);
 
-SEXP new_INTEGER_from_Linteger(SEXP x);
+SEXP new_INTEGER_from_LLint(SEXP x);
 
-SEXP new_NUMERIC_from_Linteger(SEXP x);
+SEXP new_NUMERIC_from_LLint(SEXP x);
 
-SEXP new_CHARACTER_from_Linteger(SEXP x);
+SEXP new_CHARACTER_from_LLint(SEXP x);
 
 
 /* subsetting_utils.c */
@@ -560,20 +597,18 @@ SEXP _list_as_data_frame(
 
 /* logical_utils.c */
 
-SEXP logical_as_compact_bitvector(SEXP x);
+SEXP logical_sum(
+	SEXP x,
+	SEXP na_rm
+);
 
-SEXP compact_bitvector_as_logical(SEXP x, SEXP length_out);
-
-SEXP subset_compact_bitvector(SEXP x, SEXP subscript);
-
-SEXP compact_bitvector_bit_count(SEXP x);
-
-SEXP compact_bitvector_last_bit(SEXP x);
-
-SEXP compact_bitvector_set_op(SEXP query, SEXP ref, SEXP align);
+SEXP logical2_sum(
+	SEXP x,
+	SEXP na_rm
+);
 
 
-/* int_utils.c */
+/* integer_utils.c */
 
 SEXP Integer_any_missing_or_outside(SEXP x, SEXP lower, SEXP upper);
 
@@ -755,7 +790,7 @@ SEXP findIntervalAndStartFromWidth(
 );
 
 
-/* str_utils.c */
+/* character_utils.c */
 
 SEXP unstrsplit_list(SEXP x, SEXP sep);
 
